# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class Bgp4VpnBgpAdVplsRange(Base):
	"""The Bgp4VpnBgpAdVplsRange class encapsulates a user managed bgp4VpnBgpAdVplsRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the Bgp4VpnBgpAdVplsRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'bgp4VpnBgpAdVplsRange'

	def __init__(self, parent):
		super(Bgp4VpnBgpAdVplsRange, self).__init__(parent)

	@property
	def Enabled(self):
		"""If true, enables one BGP AD VPLS.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def RouteDistinguisherAsNumber(self):
		"""This option is available for use if Distinguish Type is set to AS. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeDistinguisherAsNumber')
	@RouteDistinguisherAsNumber.setter
	def RouteDistinguisherAsNumber(self, value):
		self._set_attribute('routeDistinguisherAsNumber', value)

	@property
	def RouteDistinguisherAsNumberStep(self):
		"""This option is available for use if Distinguish Type is set to AS. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeDistinguisherAsNumberStep')
	@RouteDistinguisherAsNumberStep.setter
	def RouteDistinguisherAsNumberStep(self, value):
		self._set_attribute('routeDistinguisherAsNumberStep', value)

	@property
	def RouteDistinguisherAssignedNumber(self):
		"""The distinguisher assigned number. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeDistinguisherAssignedNumber')
	@RouteDistinguisherAssignedNumber.setter
	def RouteDistinguisherAssignedNumber(self, value):
		self._set_attribute('routeDistinguisherAssignedNumber', value)

	@property
	def RouteDistinguisherAssignedNumberStep(self):
		"""The distinguisher assigned number. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeDistinguisherAssignedNumberStep')
	@RouteDistinguisherAssignedNumberStep.setter
	def RouteDistinguisherAssignedNumberStep(self, value):
		self._set_attribute('routeDistinguisherAssignedNumberStep', value)

	@property
	def RouteDistinguisherIpAddress(self):
		"""Available for use only if the IPv4 Input is set to IP

		Returns:
			str
		"""
		return self._get_attribute('routeDistinguisherIpAddress')
	@RouteDistinguisherIpAddress.setter
	def RouteDistinguisherIpAddress(self, value):
		self._set_attribute('routeDistinguisherIpAddress', value)

	@property
	def RouteDistinguisherIpAddressStep(self):
		"""Available for use only if the IPv4 Input is set to IP.

		Returns:
			str
		"""
		return self._get_attribute('routeDistinguisherIpAddressStep')
	@RouteDistinguisherIpAddressStep.setter
	def RouteDistinguisherIpAddressStep(self, value):
		self._set_attribute('routeDistinguisherIpAddressStep', value)

	@property
	def RouteDistinguisherType(self):
		"""The RD type, one of AS and IP.

		Returns:
			str(asNumber|ipAddress)
		"""
		return self._get_attribute('routeDistinguisherType')
	@RouteDistinguisherType.setter
	def RouteDistinguisherType(self, value):
		self._set_attribute('routeDistinguisherType', value)

	@property
	def RouteTargetAsNumber(self):
		"""Available for use only if Distinguish Type is set to AS.

		Returns:
			number
		"""
		return self._get_attribute('routeTargetAsNumber')
	@RouteTargetAsNumber.setter
	def RouteTargetAsNumber(self, value):
		self._set_attribute('routeTargetAsNumber', value)

	@property
	def RouteTargetAsNumberStep(self):
		"""Available for use only if Target AS Number is set to AS. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeTargetAsNumberStep')
	@RouteTargetAsNumberStep.setter
	def RouteTargetAsNumberStep(self, value):
		self._set_attribute('routeTargetAsNumberStep', value)

	@property
	def RouteTargetAssignedNumber(self):
		"""The target assigned number. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeTargetAssignedNumber')
	@RouteTargetAssignedNumber.setter
	def RouteTargetAssignedNumber(self, value):
		self._set_attribute('routeTargetAssignedNumber', value)

	@property
	def RouteTargetAssignedNumberStep(self):
		"""The target assigned number. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('routeTargetAssignedNumberStep')
	@RouteTargetAssignedNumberStep.setter
	def RouteTargetAssignedNumberStep(self, value):
		self._set_attribute('routeTargetAssignedNumberStep', value)

	@property
	def RouteTargetIpAddress(self):
		"""Available for use only if the IPv4 Input is set to IP.

		Returns:
			str
		"""
		return self._get_attribute('routeTargetIpAddress')
	@RouteTargetIpAddress.setter
	def RouteTargetIpAddress(self, value):
		self._set_attribute('routeTargetIpAddress', value)

	@property
	def RouteTargetIpAddressStep(self):
		"""Available for use only if it is set to IP. The default is 0.0.0.0.

		Returns:
			str
		"""
		return self._get_attribute('routeTargetIpAddressStep')
	@RouteTargetIpAddressStep.setter
	def RouteTargetIpAddressStep(self, value):
		self._set_attribute('routeTargetIpAddressStep', value)

	@property
	def RouteTargetType(self):
		"""The RT format, one of AS and IP. The default is AS.

		Returns:
			str(asNumber|ipAddress)
		"""
		return self._get_attribute('routeTargetType')
	@RouteTargetType.setter
	def RouteTargetType(self, value):
		self._set_attribute('routeTargetType', value)

	@property
	def UseRouteDistinguisherAsRouteTarget(self):
		"""If true, the route distinginguisher is used as the route target.

		Returns:
			bool
		"""
		return self._get_attribute('useRouteDistinguisherAsRouteTarget')
	@UseRouteDistinguisherAsRouteTarget.setter
	def UseRouteDistinguisherAsRouteTarget(self, value):
		self._set_attribute('useRouteDistinguisherAsRouteTarget', value)

	@property
	def UseVplsIdAsRouteDistinguisher(self):
		"""If true, the VPLS Id is used as the route distinguisher.

		Returns:
			bool
		"""
		return self._get_attribute('useVplsIdAsRouteDistinguisher')
	@UseVplsIdAsRouteDistinguisher.setter
	def UseVplsIdAsRouteDistinguisher(self, value):
		self._set_attribute('useVplsIdAsRouteDistinguisher', value)

	@property
	def VplsCount(self):
		"""The Integer value that indicates the number of VPLS instance emulated using this VPLS range.

		Returns:
			number
		"""
		return self._get_attribute('vplsCount')
	@VplsCount.setter
	def VplsCount(self, value):
		self._set_attribute('vplsCount', value)

	@property
	def VplsIdAsNumber(self):
		"""Available for use if VPLS Id Type is set to AS. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAsNumber')
	@VplsIdAsNumber.setter
	def VplsIdAsNumber(self, value):
		self._set_attribute('vplsIdAsNumber', value)

	@property
	def VplsIdAsNumberStep(self):
		"""Available for use only if VPLS Id Type is set to AS. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAsNumberStep')
	@VplsIdAsNumberStep.setter
	def VplsIdAsNumberStep(self, value):
		self._set_attribute('vplsIdAsNumberStep', value)

	@property
	def VplsIdAssignedNumber(self):
		"""The indicated value for the VPLS Id Assigned Number attribute. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAssignedNumber')
	@VplsIdAssignedNumber.setter
	def VplsIdAssignedNumber(self, value):
		self._set_attribute('vplsIdAssignedNumber', value)

	@property
	def VplsIdAssignedNumberStep(self):
		"""The indicated number for the VPLS Id Assigned Number attribute. The default is 0.

		Returns:
			number
		"""
		return self._get_attribute('vplsIdAssignedNumberStep')
	@VplsIdAssignedNumberStep.setter
	def VplsIdAssignedNumberStep(self, value):
		self._set_attribute('vplsIdAssignedNumberStep', value)

	@property
	def VplsIdIpAddress(self):
		"""Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0

		Returns:
			str
		"""
		return self._get_attribute('vplsIdIpAddress')
	@VplsIdIpAddress.setter
	def VplsIdIpAddress(self, value):
		self._set_attribute('vplsIdIpAddress', value)

	@property
	def VplsIdIpAddressStep(self):
		"""Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0

		Returns:
			str
		"""
		return self._get_attribute('vplsIdIpAddressStep')
	@VplsIdIpAddressStep.setter
	def VplsIdIpAddressStep(self, value):
		self._set_attribute('vplsIdIpAddressStep', value)

	@property
	def VplsIdType(self):
		"""The VPLS ID type, one of AS and IP. Default is AS.

		Returns:
			str(asNumber|ipAddress)
		"""
		return self._get_attribute('vplsIdType')
	@VplsIdType.setter
	def VplsIdType(self, value):
		self._set_attribute('vplsIdType', value)

	@property
	def VsiId(self):
		"""The VSI ID, one of concatenatePeAddress and concatenateAssignedNumber.

		Returns:
			str(concatenatePeAddress|concatenateAssignedNumber)
		"""
		return self._get_attribute('vsiId')
	@VsiId.setter
	def VsiId(self, value):
		self._set_attribute('vsiId', value)

	@property
	def VsiIdAssignedNumber(self):
		"""The indicated value for the VSI ID Assigned Number attribute.

		Returns:
			number
		"""
		return self._get_attribute('vsiIdAssignedNumber')
	@VsiIdAssignedNumber.setter
	def VsiIdAssignedNumber(self, value):
		self._set_attribute('vsiIdAssignedNumber', value)

	def update(self, Enabled=None, RouteDistinguisherAsNumber=None, RouteDistinguisherAsNumberStep=None, RouteDistinguisherAssignedNumber=None, RouteDistinguisherAssignedNumberStep=None, RouteDistinguisherIpAddress=None, RouteDistinguisherIpAddressStep=None, RouteDistinguisherType=None, RouteTargetAsNumber=None, RouteTargetAsNumberStep=None, RouteTargetAssignedNumber=None, RouteTargetAssignedNumberStep=None, RouteTargetIpAddress=None, RouteTargetIpAddressStep=None, RouteTargetType=None, UseRouteDistinguisherAsRouteTarget=None, UseVplsIdAsRouteDistinguisher=None, VplsCount=None, VplsIdAsNumber=None, VplsIdAsNumberStep=None, VplsIdAssignedNumber=None, VplsIdAssignedNumberStep=None, VplsIdIpAddress=None, VplsIdIpAddressStep=None, VplsIdType=None, VsiId=None, VsiIdAssignedNumber=None):
		"""Updates a child instance of bgp4VpnBgpAdVplsRange on the server.

		Args:
			Enabled (bool): If true, enables one BGP AD VPLS.
			RouteDistinguisherAsNumber (number): This option is available for use if Distinguish Type is set to AS. The default is 0.
			RouteDistinguisherAsNumberStep (number): This option is available for use if Distinguish Type is set to AS. The default is 0.
			RouteDistinguisherAssignedNumber (number): The distinguisher assigned number. The default is 0.
			RouteDistinguisherAssignedNumberStep (number): The distinguisher assigned number. The default is 0.
			RouteDistinguisherIpAddress (str): Available for use only if the IPv4 Input is set to IP
			RouteDistinguisherIpAddressStep (str): Available for use only if the IPv4 Input is set to IP.
			RouteDistinguisherType (str(asNumber|ipAddress)): The RD type, one of AS and IP.
			RouteTargetAsNumber (number): Available for use only if Distinguish Type is set to AS.
			RouteTargetAsNumberStep (number): Available for use only if Target AS Number is set to AS. The default is 0.
			RouteTargetAssignedNumber (number): The target assigned number. The default is 0.
			RouteTargetAssignedNumberStep (number): The target assigned number. The default is 0.
			RouteTargetIpAddress (str): Available for use only if the IPv4 Input is set to IP.
			RouteTargetIpAddressStep (str): Available for use only if it is set to IP. The default is 0.0.0.0.
			RouteTargetType (str(asNumber|ipAddress)): The RT format, one of AS and IP. The default is AS.
			UseRouteDistinguisherAsRouteTarget (bool): If true, the route distinginguisher is used as the route target.
			UseVplsIdAsRouteDistinguisher (bool): If true, the VPLS Id is used as the route distinguisher.
			VplsCount (number): The Integer value that indicates the number of VPLS instance emulated using this VPLS range.
			VplsIdAsNumber (number): Available for use if VPLS Id Type is set to AS. The default is 0.
			VplsIdAsNumberStep (number): Available for use only if VPLS Id Type is set to AS. The default is 0.
			VplsIdAssignedNumber (number): The indicated value for the VPLS Id Assigned Number attribute. The default is 0.
			VplsIdAssignedNumberStep (number): The indicated number for the VPLS Id Assigned Number attribute. The default is 0.
			VplsIdIpAddress (str): Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0
			VplsIdIpAddressStep (str): Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0
			VplsIdType (str(asNumber|ipAddress)): The VPLS ID type, one of AS and IP. Default is AS.
			VsiId (str(concatenatePeAddress|concatenateAssignedNumber)): The VSI ID, one of concatenatePeAddress and concatenateAssignedNumber.
			VsiIdAssignedNumber (number): The indicated value for the VSI ID Assigned Number attribute.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Enabled=None, RouteDistinguisherAsNumber=None, RouteDistinguisherAsNumberStep=None, RouteDistinguisherAssignedNumber=None, RouteDistinguisherAssignedNumberStep=None, RouteDistinguisherIpAddress=None, RouteDistinguisherIpAddressStep=None, RouteDistinguisherType=None, RouteTargetAsNumber=None, RouteTargetAsNumberStep=None, RouteTargetAssignedNumber=None, RouteTargetAssignedNumberStep=None, RouteTargetIpAddress=None, RouteTargetIpAddressStep=None, RouteTargetType=None, UseRouteDistinguisherAsRouteTarget=None, UseVplsIdAsRouteDistinguisher=None, VplsCount=None, VplsIdAsNumber=None, VplsIdAsNumberStep=None, VplsIdAssignedNumber=None, VplsIdAssignedNumberStep=None, VplsIdIpAddress=None, VplsIdIpAddressStep=None, VplsIdType=None, VsiId=None, VsiIdAssignedNumber=None):
		"""Adds a new bgp4VpnBgpAdVplsRange node on the server and retrieves it in this instance.

		Args:
			Enabled (bool): If true, enables one BGP AD VPLS.
			RouteDistinguisherAsNumber (number): This option is available for use if Distinguish Type is set to AS. The default is 0.
			RouteDistinguisherAsNumberStep (number): This option is available for use if Distinguish Type is set to AS. The default is 0.
			RouteDistinguisherAssignedNumber (number): The distinguisher assigned number. The default is 0.
			RouteDistinguisherAssignedNumberStep (number): The distinguisher assigned number. The default is 0.
			RouteDistinguisherIpAddress (str): Available for use only if the IPv4 Input is set to IP
			RouteDistinguisherIpAddressStep (str): Available for use only if the IPv4 Input is set to IP.
			RouteDistinguisherType (str(asNumber|ipAddress)): The RD type, one of AS and IP.
			RouteTargetAsNumber (number): Available for use only if Distinguish Type is set to AS.
			RouteTargetAsNumberStep (number): Available for use only if Target AS Number is set to AS. The default is 0.
			RouteTargetAssignedNumber (number): The target assigned number. The default is 0.
			RouteTargetAssignedNumberStep (number): The target assigned number. The default is 0.
			RouteTargetIpAddress (str): Available for use only if the IPv4 Input is set to IP.
			RouteTargetIpAddressStep (str): Available for use only if it is set to IP. The default is 0.0.0.0.
			RouteTargetType (str(asNumber|ipAddress)): The RT format, one of AS and IP. The default is AS.
			UseRouteDistinguisherAsRouteTarget (bool): If true, the route distinginguisher is used as the route target.
			UseVplsIdAsRouteDistinguisher (bool): If true, the VPLS Id is used as the route distinguisher.
			VplsCount (number): The Integer value that indicates the number of VPLS instance emulated using this VPLS range.
			VplsIdAsNumber (number): Available for use if VPLS Id Type is set to AS. The default is 0.
			VplsIdAsNumberStep (number): Available for use only if VPLS Id Type is set to AS. The default is 0.
			VplsIdAssignedNumber (number): The indicated value for the VPLS Id Assigned Number attribute. The default is 0.
			VplsIdAssignedNumberStep (number): The indicated number for the VPLS Id Assigned Number attribute. The default is 0.
			VplsIdIpAddress (str): Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0
			VplsIdIpAddressStep (str): Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0
			VplsIdType (str(asNumber|ipAddress)): The VPLS ID type, one of AS and IP. Default is AS.
			VsiId (str(concatenatePeAddress|concatenateAssignedNumber)): The VSI ID, one of concatenatePeAddress and concatenateAssignedNumber.
			VsiIdAssignedNumber (number): The indicated value for the VSI ID Assigned Number attribute.

		Returns:
			self: This instance with all currently retrieved bgp4VpnBgpAdVplsRange data using find and the newly added bgp4VpnBgpAdVplsRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the bgp4VpnBgpAdVplsRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, Enabled=None, RouteDistinguisherAsNumber=None, RouteDistinguisherAsNumberStep=None, RouteDistinguisherAssignedNumber=None, RouteDistinguisherAssignedNumberStep=None, RouteDistinguisherIpAddress=None, RouteDistinguisherIpAddressStep=None, RouteDistinguisherType=None, RouteTargetAsNumber=None, RouteTargetAsNumberStep=None, RouteTargetAssignedNumber=None, RouteTargetAssignedNumberStep=None, RouteTargetIpAddress=None, RouteTargetIpAddressStep=None, RouteTargetType=None, UseRouteDistinguisherAsRouteTarget=None, UseVplsIdAsRouteDistinguisher=None, VplsCount=None, VplsIdAsNumber=None, VplsIdAsNumberStep=None, VplsIdAssignedNumber=None, VplsIdAssignedNumberStep=None, VplsIdIpAddress=None, VplsIdIpAddressStep=None, VplsIdType=None, VsiId=None, VsiIdAssignedNumber=None):
		"""Finds and retrieves bgp4VpnBgpAdVplsRange data from the server.

		All named parameters support regex and can be used to selectively retrieve bgp4VpnBgpAdVplsRange data from the server.
		By default the find method takes no parameters and will retrieve all bgp4VpnBgpAdVplsRange data from the server.

		Args:
			Enabled (bool): If true, enables one BGP AD VPLS.
			RouteDistinguisherAsNumber (number): This option is available for use if Distinguish Type is set to AS. The default is 0.
			RouteDistinguisherAsNumberStep (number): This option is available for use if Distinguish Type is set to AS. The default is 0.
			RouteDistinguisherAssignedNumber (number): The distinguisher assigned number. The default is 0.
			RouteDistinguisherAssignedNumberStep (number): The distinguisher assigned number. The default is 0.
			RouteDistinguisherIpAddress (str): Available for use only if the IPv4 Input is set to IP
			RouteDistinguisherIpAddressStep (str): Available for use only if the IPv4 Input is set to IP.
			RouteDistinguisherType (str(asNumber|ipAddress)): The RD type, one of AS and IP.
			RouteTargetAsNumber (number): Available for use only if Distinguish Type is set to AS.
			RouteTargetAsNumberStep (number): Available for use only if Target AS Number is set to AS. The default is 0.
			RouteTargetAssignedNumber (number): The target assigned number. The default is 0.
			RouteTargetAssignedNumberStep (number): The target assigned number. The default is 0.
			RouteTargetIpAddress (str): Available for use only if the IPv4 Input is set to IP.
			RouteTargetIpAddressStep (str): Available for use only if it is set to IP. The default is 0.0.0.0.
			RouteTargetType (str(asNumber|ipAddress)): The RT format, one of AS and IP. The default is AS.
			UseRouteDistinguisherAsRouteTarget (bool): If true, the route distinginguisher is used as the route target.
			UseVplsIdAsRouteDistinguisher (bool): If true, the VPLS Id is used as the route distinguisher.
			VplsCount (number): The Integer value that indicates the number of VPLS instance emulated using this VPLS range.
			VplsIdAsNumber (number): Available for use if VPLS Id Type is set to AS. The default is 0.
			VplsIdAsNumberStep (number): Available for use only if VPLS Id Type is set to AS. The default is 0.
			VplsIdAssignedNumber (number): The indicated value for the VPLS Id Assigned Number attribute. The default is 0.
			VplsIdAssignedNumberStep (number): The indicated number for the VPLS Id Assigned Number attribute. The default is 0.
			VplsIdIpAddress (str): Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0
			VplsIdIpAddressStep (str): Available for use only if the route VPLS Id Type is set to IP. The default is 0.0.0.0
			VplsIdType (str(asNumber|ipAddress)): The VPLS ID type, one of AS and IP. Default is AS.
			VsiId (str(concatenatePeAddress|concatenateAssignedNumber)): The VSI ID, one of concatenatePeAddress and concatenateAssignedNumber.
			VsiIdAssignedNumber (number): The indicated value for the VSI ID Assigned Number attribute.

		Returns:
			self: This instance with matching bgp4VpnBgpAdVplsRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of bgp4VpnBgpAdVplsRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the bgp4VpnBgpAdVplsRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class AdvancedCVFilters(Base):
	"""The AdvancedCVFilters class encapsulates a user managed advancedCVFilters node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the AdvancedCVFilters property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'advancedCVFilters'

	def __init__(self, parent):
		super(AdvancedCVFilters, self).__init__(parent)

	@property
	def AvailableFilterOptions(self):
		"""Returns a list of all the statistics and the operations available for filtering. Note- A protocol and a grouping must be set in order for this to work.

		Returns:
			str
		"""
		return self._get_attribute('availableFilterOptions')

	@property
	def AvailableGroupingOptions(self):
		"""Returns all the grouping options available. Note - A protocol must be set in order for this to work.

		Returns:
			str
		"""
		return self._get_attribute('availableGroupingOptions')

	@property
	def Caption(self):
		"""Sets a name for the filter.

		Returns:
			str
		"""
		return self._get_attribute('caption')
	@Caption.setter
	def Caption(self, value):
		self._set_attribute('caption', value)

	@property
	def Expression(self):
		"""Specifies the filter body. This is a string that must have the specific format. This can be empty or no filter.The available operations and statistics can be obtained from availableFilterOptions.

		Returns:
			str
		"""
		return self._get_attribute('expression')
	@Expression.setter
	def Expression(self, value):
		self._set_attribute('expression', value)

	@property
	def Grouping(self):
		"""Sets a grouping for the filter.

		Returns:
			str
		"""
		return self._get_attribute('grouping')
	@Grouping.setter
	def Grouping(self, value):
		self._set_attribute('grouping', value)

	@property
	def Protocol(self):
		"""Sets a protocol for the filter.

		Returns:
			str
		"""
		return self._get_attribute('protocol')
	@Protocol.setter
	def Protocol(self, value):
		self._set_attribute('protocol', value)

	@property
	def SortingStats(self):
		"""Specifies the list of statistics by which the view is sorted.

		Returns:
			str
		"""
		return self._get_attribute('sortingStats')
	@SortingStats.setter
	def SortingStats(self, value):
		self._set_attribute('sortingStats', value)

	def update(self, Caption=None, Expression=None, Grouping=None, Protocol=None, SortingStats=None):
		"""Updates a child instance of advancedCVFilters on the server.

		Args:
			Caption (str): Sets a name for the filter.
			Expression (str): Specifies the filter body. This is a string that must have the specific format. This can be empty or no filter.The available operations and statistics can be obtained from availableFilterOptions.
			Grouping (str): Sets a grouping for the filter.
			Protocol (str): Sets a protocol for the filter.
			SortingStats (str): Specifies the list of statistics by which the view is sorted.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, Caption=None, Expression=None, Grouping=None, Protocol=None, SortingStats=None):
		"""Adds a new advancedCVFilters node on the server and retrieves it in this instance.

		Args:
			Caption (str): Sets a name for the filter.
			Expression (str): Specifies the filter body. This is a string that must have the specific format. This can be empty or no filter.The available operations and statistics can be obtained from availableFilterOptions.
			Grouping (str): Sets a grouping for the filter.
			Protocol (str): Sets a protocol for the filter.
			SortingStats (str): Specifies the list of statistics by which the view is sorted.

		Returns:
			self: This instance with all currently retrieved advancedCVFilters data using find and the newly added advancedCVFilters data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the advancedCVFilters data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, AvailableFilterOptions=None, AvailableGroupingOptions=None, Caption=None, Expression=None, Grouping=None, Protocol=None, SortingStats=None):
		"""Finds and retrieves advancedCVFilters data from the server.

		All named parameters support regex and can be used to selectively retrieve advancedCVFilters data from the server.
		By default the find method takes no parameters and will retrieve all advancedCVFilters data from the server.

		Args:
			AvailableFilterOptions (str): Returns a list of all the statistics and the operations available for filtering. Note- A protocol and a grouping must be set in order for this to work.
			AvailableGroupingOptions (str): Returns all the grouping options available. Note - A protocol must be set in order for this to work.
			Caption (str): Sets a name for the filter.
			Expression (str): Specifies the filter body. This is a string that must have the specific format. This can be empty or no filter.The available operations and statistics can be obtained from availableFilterOptions.
			Grouping (str): Sets a grouping for the filter.
			Protocol (str): Sets a protocol for the filter.
			SortingStats (str): Specifies the list of statistics by which the view is sorted.

		Returns:
			self: This instance with matching advancedCVFilters data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of advancedCVFilters data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the advancedCVFilters data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class TableFeaturePropertiesTrigger(Base):
	"""The TableFeaturePropertiesTrigger class encapsulates a system managed tableFeaturePropertiesTrigger node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the TableFeaturePropertiesTrigger property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'tableFeaturePropertiesTrigger'

	def __init__(self, parent):
		super(TableFeaturePropertiesTrigger, self).__init__(parent)

	@property
	def ApplyAction(self):
		"""An instance of the ApplyAction class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applyaction.ApplyAction)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applyaction import ApplyAction
		return ApplyAction(self)._select()

	@property
	def ApplySetField(self):
		"""An instance of the ApplySetField class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applysetfield.ApplySetField)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.applysetfield import ApplySetField
		return ApplySetField(self)._select()

	@property
	def Experimenter(self):
		"""An instance of the Experimenter class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.experimenter.Experimenter)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.experimenter import Experimenter
		return Experimenter(self)._select()

	@property
	def Instruction(self):
		"""An instance of the Instruction class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instruction.Instruction)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.instruction import Instruction
		return Instruction(self)._select()

	@property
	def Match(self):
		"""An instance of the Match class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.match.Match)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.match import Match
		return Match(self)._select()

	@property
	def NextTable(self):
		"""An instance of the NextTable class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.nexttable.NextTable)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.nexttable import NextTable
		return NextTable(self)._select()

	@property
	def Wildcards(self):
		"""An instance of the Wildcards class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.wildcards.Wildcards)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.wildcards import Wildcards
		return Wildcards(self)._select()

	@property
	def WriteAction(self):
		"""An instance of the WriteAction class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writeaction.WriteAction)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writeaction import WriteAction
		return WriteAction(self)._select()

	@property
	def WriteSetField(self):
		"""An instance of the WriteSetField class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writesetfield.WriteSetField)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.openflow.writesetfield import WriteSetField
		return WriteSetField(self)._select()

	@property
	def EnableApplyAction(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableApplyAction')
	@EnableApplyAction.setter
	def EnableApplyAction(self, value):
		self._set_attribute('enableApplyAction', value)

	@property
	def EnableApplyActionMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableApplyActionMiss')
	@EnableApplyActionMiss.setter
	def EnableApplyActionMiss(self, value):
		self._set_attribute('enableApplyActionMiss', value)

	@property
	def EnableApplySetField(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableApplySetField')
	@EnableApplySetField.setter
	def EnableApplySetField(self, value):
		self._set_attribute('enableApplySetField', value)

	@property
	def EnableApplySetFieldMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableApplySetFieldMiss')
	@EnableApplySetFieldMiss.setter
	def EnableApplySetFieldMiss(self, value):
		self._set_attribute('enableApplySetFieldMiss', value)

	@property
	def EnableExperimenter(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableExperimenter')
	@EnableExperimenter.setter
	def EnableExperimenter(self, value):
		self._set_attribute('enableExperimenter', value)

	@property
	def EnableExperimenterMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableExperimenterMiss')
	@EnableExperimenterMiss.setter
	def EnableExperimenterMiss(self, value):
		self._set_attribute('enableExperimenterMiss', value)

	@property
	def EnableInstruction(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableInstruction')
	@EnableInstruction.setter
	def EnableInstruction(self, value):
		self._set_attribute('enableInstruction', value)

	@property
	def EnableInstructionMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableInstructionMiss')
	@EnableInstructionMiss.setter
	def EnableInstructionMiss(self, value):
		self._set_attribute('enableInstructionMiss', value)

	@property
	def EnableMatch(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableMatch')
	@EnableMatch.setter
	def EnableMatch(self, value):
		self._set_attribute('enableMatch', value)

	@property
	def EnableNextTable(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableNextTable')
	@EnableNextTable.setter
	def EnableNextTable(self, value):
		self._set_attribute('enableNextTable', value)

	@property
	def EnableNextTableMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableNextTableMiss')
	@EnableNextTableMiss.setter
	def EnableNextTableMiss(self, value):
		self._set_attribute('enableNextTableMiss', value)

	@property
	def EnableWildCard(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableWildCard')
	@EnableWildCard.setter
	def EnableWildCard(self, value):
		self._set_attribute('enableWildCard', value)

	@property
	def EnableWriteAction(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableWriteAction')
	@EnableWriteAction.setter
	def EnableWriteAction(self, value):
		self._set_attribute('enableWriteAction', value)

	@property
	def EnableWriteActionMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableWriteActionMiss')
	@EnableWriteActionMiss.setter
	def EnableWriteActionMiss(self, value):
		self._set_attribute('enableWriteActionMiss', value)

	@property
	def EnableWriteSetField(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableWriteSetField')
	@EnableWriteSetField.setter
	def EnableWriteSetField(self, value):
		self._set_attribute('enableWriteSetField', value)

	@property
	def EnableWriteSetFieldMiss(self):
		"""NOT DEFINED

		Returns:
			bool
		"""
		return self._get_attribute('enableWriteSetFieldMiss')
	@EnableWriteSetFieldMiss.setter
	def EnableWriteSetFieldMiss(self, value):
		self._set_attribute('enableWriteSetFieldMiss', value)

	def update(self, EnableApplyAction=None, EnableApplyActionMiss=None, EnableApplySetField=None, EnableApplySetFieldMiss=None, EnableExperimenter=None, EnableExperimenterMiss=None, EnableInstruction=None, EnableInstructionMiss=None, EnableMatch=None, EnableNextTable=None, EnableNextTableMiss=None, EnableWildCard=None, EnableWriteAction=None, EnableWriteActionMiss=None, EnableWriteSetField=None, EnableWriteSetFieldMiss=None):
		"""Updates a child instance of tableFeaturePropertiesTrigger on the server.

		Args:
			EnableApplyAction (bool): NOT DEFINED
			EnableApplyActionMiss (bool): NOT DEFINED
			EnableApplySetField (bool): NOT DEFINED
			EnableApplySetFieldMiss (bool): NOT DEFINED
			EnableExperimenter (bool): NOT DEFINED
			EnableExperimenterMiss (bool): NOT DEFINED
			EnableInstruction (bool): NOT DEFINED
			EnableInstructionMiss (bool): NOT DEFINED
			EnableMatch (bool): NOT DEFINED
			EnableNextTable (bool): NOT DEFINED
			EnableNextTableMiss (bool): NOT DEFINED
			EnableWildCard (bool): NOT DEFINED
			EnableWriteAction (bool): NOT DEFINED
			EnableWriteActionMiss (bool): NOT DEFINED
			EnableWriteSetField (bool): NOT DEFINED
			EnableWriteSetFieldMiss (bool): NOT DEFINED

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, EnableApplyAction=None, EnableApplyActionMiss=None, EnableApplySetField=None, EnableApplySetFieldMiss=None, EnableExperimenter=None, EnableExperimenterMiss=None, EnableInstruction=None, EnableInstructionMiss=None, EnableMatch=None, EnableNextTable=None, EnableNextTableMiss=None, EnableWildCard=None, EnableWriteAction=None, EnableWriteActionMiss=None, EnableWriteSetField=None, EnableWriteSetFieldMiss=None):
		"""Finds and retrieves tableFeaturePropertiesTrigger data from the server.

		All named parameters support regex and can be used to selectively retrieve tableFeaturePropertiesTrigger data from the server.
		By default the find method takes no parameters and will retrieve all tableFeaturePropertiesTrigger data from the server.

		Args:
			EnableApplyAction (bool): NOT DEFINED
			EnableApplyActionMiss (bool): NOT DEFINED
			EnableApplySetField (bool): NOT DEFINED
			EnableApplySetFieldMiss (bool): NOT DEFINED
			EnableExperimenter (bool): NOT DEFINED
			EnableExperimenterMiss (bool): NOT DEFINED
			EnableInstruction (bool): NOT DEFINED
			EnableInstructionMiss (bool): NOT DEFINED
			EnableMatch (bool): NOT DEFINED
			EnableNextTable (bool): NOT DEFINED
			EnableNextTableMiss (bool): NOT DEFINED
			EnableWildCard (bool): NOT DEFINED
			EnableWriteAction (bool): NOT DEFINED
			EnableWriteActionMiss (bool): NOT DEFINED
			EnableWriteSetField (bool): NOT DEFINED
			EnableWriteSetFieldMiss (bool): NOT DEFINED

		Returns:
			self: This instance with matching tableFeaturePropertiesTrigger data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of tableFeaturePropertiesTrigger data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the tableFeaturePropertiesTrigger data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class IsisL3Router(Base):
	"""The IsisL3Router class encapsulates a system managed isisL3Router node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the IsisL3Router property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'isisL3Router'

	def __init__(self, parent):
		super(IsisL3Router, self).__init__(parent)

	@property
	def IsisBierSubDomainList(self):
		"""An instance of the IsisBierSubDomainList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisbiersubdomainlist.IsisBierSubDomainList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isisbiersubdomainlist import IsisBierSubDomainList
		return IsisBierSubDomainList(self)._select()

	@property
	def IsisMappingServerIPV4List(self):
		"""An instance of the IsisMappingServerIPV4List class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isismappingserveripv4list.IsisMappingServerIPV4List)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isismappingserveripv4list import IsisMappingServerIPV4List
		return IsisMappingServerIPV4List(self)._select()

	@property
	def IsisMappingServerIPV6List(self):
		"""An instance of the IsisMappingServerIPV6List class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isismappingserveripv6list.IsisMappingServerIPV6List)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isismappingserveripv6list import IsisMappingServerIPV6List
		return IsisMappingServerIPV6List(self)._select()

	@property
	def IsisMultiTopologyValuesList(self):
		"""An instance of the IsisMultiTopologyValuesList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isismultitopologyvalueslist.IsisMultiTopologyValuesList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isismultitopologyvalueslist import IsisMultiTopologyValuesList
		return IsisMultiTopologyValuesList(self)

	@property
	def IsisSRAlgorithmList(self):
		"""An instance of the IsisSRAlgorithmList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissralgorithmlist.IsisSRAlgorithmList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissralgorithmlist import IsisSRAlgorithmList
		return IsisSRAlgorithmList(self)

	@property
	def IsisSRGBRangeSubObjectsList(self):
		"""An instance of the IsisSRGBRangeSubObjectsList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrgbrangesubobjectslist.IsisSRGBRangeSubObjectsList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrgbrangesubobjectslist import IsisSRGBRangeSubObjectsList
		return IsisSRGBRangeSubObjectsList(self)

	@property
	def IsisSRLBDescriptorList(self):
		"""An instance of the IsisSRLBDescriptorList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrlbdescriptorlist.IsisSRLBDescriptorList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrlbdescriptorlist import IsisSRLBDescriptorList
		return IsisSRLBDescriptorList(self)

	@property
	def IsisSRTunnelList(self):
		"""An instance of the IsisSRTunnelList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrtunnellist.IsisSRTunnelList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrtunnellist import IsisSRTunnelList
		return IsisSRTunnelList(self)._select()

	@property
	def IsisSRv6LocatorEntryList(self):
		"""An instance of the IsisSRv6LocatorEntryList class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrv6locatorentrylist.IsisSRv6LocatorEntryList)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.isissrv6locatorentrylist import IsisSRv6LocatorEntryList
		return IsisSRv6LocatorEntryList(self)._select()

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def BIERNodePrefix(self):
		"""Node Prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('BIERNodePrefix')

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def AdvertiseNodeMsd(self):
		"""Advertise Node MSD

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('advertiseNodeMsd')

	@property
	def AdvertiseSRLB(self):
		"""Enables advertisement of Segment Routing Local Block (SRLB) Sub-Tlv in Router Capability Tlv

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('advertiseSRLB')

	@property
	def AdvertiseSRMSPreference(self):
		"""Advertise SRMS Preference sub-TLV in Router capability TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('advertiseSRMSPreference')

	@property
	def Algorithm(self):
		"""DEPRECATED Algorithm

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('algorithm')

	@property
	def AreaAddresses(self):
		"""DEPRECATED Area Addresses

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('areaAddresses')

	@property
	def AreaAuthenticationType(self):
		"""DEPRECATED Area Authentication Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('areaAuthenticationType')

	@property
	def AreaTransmitPasswordOrMD5Key(self):
		"""DEPRECATED Area Transmit Password / MD5-Key

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('areaTransmitPasswordOrMD5Key')

	@property
	def Attached(self):
		"""DEPRECATED Attached

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('attached')

	@property
	def BIERIPv6NodePrefix(self):
		"""DEPRECATED IPv6 Node Prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bIERIPv6NodePrefix')

	@property
	def BierNFlag(self):
		"""DEPRECATED Nodal prefix flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bierNFlag')

	@property
	def BierRFlag(self):
		"""DEPRECATED Redistribution flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('bierRFlag')

	@property
	def CSNPInterval(self):
		"""DEPRECATED CSNP Interval (ms)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('cSNPInterval')

	@property
	def ConfigureSIDIndexLabel(self):
		"""DEPRECATED Configure SID/Index/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureSIDIndexLabel')

	@property
	def Count(self):
		"""DEPRECATED Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DBit(self):
		"""DEPRECATED When the IS-IS Router CAPABILITY TLV is leaked from level-2 to level-1, the D bit MUST be set, else it should be clear

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dBit')

	@property
	def DBitForSRv6Cap(self):
		"""DEPRECATED When the IS-IS Router CAPABILITY TLV is leaked from level-2 to level-1, the D bit MUST be set, else it should be clear

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('dBitForSRv6Cap')

	@property
	def DescriptiveName(self):
		"""DEPRECATED Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def DiscardLSPs(self):
		"""DEPRECATED Discard LSPs

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('discardLSPs')

	@property
	def Distribution(self):
		"""DEPRECATED Distribution

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('distribution')

	@property
	def DomainAuthenticationType(self):
		"""DEPRECATED Domain Authentication Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('domainAuthenticationType')

	@property
	def DomainTransmitPasswordOrMD5Key(self):
		"""DEPRECATED Domain Transmit Password / MD5-Key

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('domainTransmitPasswordOrMD5Key')

	@property
	def EFlag(self):
		"""DEPRECATED Explicit NULL flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('eFlag')

	@property
	def EnableBIER(self):
		"""DEPRECATED Enable BIER

		Returns:
			bool
		"""
		return self._get_attribute('enableBIER')
	@EnableBIER.setter
	def EnableBIER(self, value):
		self._set_attribute('enableBIER', value)

	@property
	def EnableHelloPadding(self):
		"""DEPRECATED Enable Hello Padding

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableHelloPadding')

	@property
	def EnableHitlessRestart(self):
		"""DEPRECATED Enable Hitless Restart

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableHitlessRestart')

	@property
	def EnableHostName(self):
		"""DEPRECATED Enable Host Name

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableHostName')

	@property
	def EnableMTIPv6(self):
		"""DEPRECATED Enable MT for IPv6

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableMTIPv6')

	@property
	def EnableMappingServer(self):
		"""DEPRECATED This ensures whether the ISIS router will behave as a Segment Routing Mapping Server (SRMS) or not.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableMappingServer')

	@property
	def EnableSR(self):
		"""DEPRECATED Enable Segment Routing

		Returns:
			bool
		"""
		return self._get_attribute('enableSR')
	@EnableSR.setter
	def EnableSR(self, value):
		self._set_attribute('enableSR', value)

	@property
	def EnableTE(self):
		"""DEPRECATED Enable TE

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableTE')

	@property
	def EnableWMforTE(self):
		"""DEPRECATED Hidden field is to disable wide Metric, when user disable TE Router conditionally

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableWMforTE')

	@property
	def EnableWideMetric(self):
		"""DEPRECATED Enable Wide Metric

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('enableWideMetric')

	@property
	def Errors(self):
		"""DEPRECATED A list of errors that have occurred

		Returns:
			list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))
		"""
		return self._get_attribute('errors')

	@property
	def HitlessRestartMode(self):
		"""DEPRECATED Restart Mode

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hitlessRestartMode')

	@property
	def HitlessRestartTime(self):
		"""DEPRECATED Restart Time

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hitlessRestartTime')

	@property
	def HitlessRestartVersion(self):
		"""DEPRECATED Restart Version

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hitlessRestartVersion')

	@property
	def HostName(self):
		"""DEPRECATED Host Name

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('hostName')

	@property
	def IgnoreReceiveMD5(self):
		"""DEPRECATED Ignore Receive MD5

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ignoreReceiveMD5')

	@property
	def IncludeMaxSlMsd(self):
		"""DEPRECATED If set, then Include Maximum Segment Left MSD in SRv6 capability

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeMaxSlMsd')

	@property
	def IncludeMaximumEndDMsd(self):
		"""DEPRECATED If set, then include Maximum End D MSD in SRv6 capability

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeMaximumEndDMsd')

	@property
	def IncludeMaximumEndPopMsd(self):
		"""DEPRECATED If set, then include Max-End-Pop-MSD in SRv6 capability

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeMaximumEndPopMsd')

	@property
	def IncludeMaximumTEncapMsd(self):
		"""DEPRECATED If set, then include Maximum T.Encap MSD in SRv6 capability

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeMaximumTEncapMsd')

	@property
	def IncludeMaximumTInsertMsd(self):
		"""DEPRECATED If set, then include Maximum T.Insert MSD in SRv6 capability

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includeMaximumTInsertMsd')

	@property
	def IncludePrefixAttrFlags(self):
		"""DEPRECATED Include Prefix Attributes Flags

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('includePrefixAttrFlags')

	@property
	def InterLSPsOrMGroupPDUBurstGap(self):
		"""DEPRECATED Inter LSPs/MGROUP-PDUs Burst Gap (ms)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('interLSPsOrMGroupPDUBurstGap')

	@property
	def Ipv4Flag(self):
		"""DEPRECATED If set, then the router is capable of processing SR MPLS encapsulated IPv4 packets on all interfaces.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4Flag')

	@property
	def Ipv6Flag(self):
		"""DEPRECATED If set, then the router is capable of processing SR MPLS encapsulated IPv6 packets on all interfaces.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6Flag')

	@property
	def Ipv6NodePrefix(self):
		"""DEPRECATED IPv6 Node SID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6NodePrefix')

	@property
	def Ipv6Srh(self):
		"""DEPRECATED This is the SR-IPv6 flag. If set to true, then this enables the SRv6 capability on the router If set to false, then this enables the MPLS SR capability on the router

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv6Srh')

	@property
	def LFlag(self):
		"""DEPRECATED Local Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lFlag')

	@property
	def LSPLifetime(self):
		"""DEPRECATED LSP Rifetime (sec)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lSPLifetime')

	@property
	def LSPRefreshRate(self):
		"""DEPRECATED LSP Refresh Rate (sec)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lSPRefreshRate')

	@property
	def LSPorMGroupPDUMinTransmissionInterval(self):
		"""DEPRECATED LSP/MGROUP-PDU Min Transmission Interval (ms)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('lSPorMGroupPDUMinTransmissionInterval')

	@property
	def LocalSystemID(self):
		"""DEPRECATED System ID

		Returns:
			list(str)
		"""
		return self._get_attribute('localSystemID')

	@property
	def LocatorCount(self):
		"""DEPRECATED Locator Count

		Returns:
			number
		"""
		return self._get_attribute('locatorCount')
	@LocatorCount.setter
	def LocatorCount(self, value):
		self._set_attribute('locatorCount', value)

	@property
	def Mask(self):
		"""DEPRECATED Mask

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('mask')

	@property
	def MaxAreaAddresses(self):
		"""DEPRECATED Maximum Area Addresses

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxAreaAddresses')

	@property
	def MaxEndDMsd(self):
		"""DEPRECATED This field specifies the maximum number of SIDs in an SRH when applying End.DX6 and End.DT6 functions. If this field is zero, then the router cannot apply End.DX6 or End.DT6 functions. If the extension header is right underneath the outer IPv6, header is an SRH.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxEndDMsd')

	@property
	def MaxEndPopMsd(self):
		"""DEPRECATED This field specifies the maximum number of SIDs in the top MSD in an MSD stack that the router can apply PSP or USP flavors to. If the value of this field is zero, then the router cannot apply PSP or USP flavors.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxEndPopMsd')

	@property
	def MaxLSPSize(self):
		"""DEPRECATED Max LSP Size

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxLSPSize')

	@property
	def MaxLSPsOrMGroupPDUsPerBurst(self):
		"""DEPRECATED Max LSPs/MGROUP-PDUs Per Burst

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxLSPsOrMGroupPDUsPerBurst')

	@property
	def MaxSlMsd(self):
		"""DEPRECATED This field specifies the maximum value of the Segments Left (SL) MSD field in the SRH of a received packet before applying the function associated with a SID.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxSlMsd')

	@property
	def MaxTEncap(self):
		"""DEPRECATED This field specifies the maximum number of SIDs that can be included as part of the T.Encap behavior. If this field is zero and the E flag is set, then the router can apply T.Encap by encapsulating the incoming packet in another IPv6 header without SRH, it is the same way IPinIP encapsulation is performed. If the E flag is clear, then this field SHOULD be transmitted as zero and MUST be ignored on receipt.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxTEncap')

	@property
	def MaxTInsertMsd(self):
		"""DEPRECATED This field specifies the maximum number of SIDs that can be inserted as part of the T.insert behavior. If the value of this field is zero, then the router cannot apply any variation of the T.insert behavior.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('maxTInsertMsd')

	@property
	def MtCount(self):
		"""DEPRECATED MT Count

		Returns:
			number
		"""
		return self._get_attribute('mtCount')
	@MtCount.setter
	def MtCount(self, value):
		self._set_attribute('mtCount', value)

	@property
	def NFlag(self):
		"""DEPRECATED Nodal prefix flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('nFlag')

	@property
	def Name(self):
		"""DEPRECATED Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NoOfBIERSubDomains(self):
		"""DEPRECATED Number of BIER Sub Domains

		Returns:
			number
		"""
		return self._get_attribute('noOfBIERSubDomains')
	@NoOfBIERSubDomains.setter
	def NoOfBIERSubDomains(self, value):
		self._set_attribute('noOfBIERSubDomains', value)

	@property
	def NoOfSRTunnels(self):
		"""DEPRECATED Number of MPLS SR Tunnels

		Returns:
			number
		"""
		return self._get_attribute('noOfSRTunnels')
	@NoOfSRTunnels.setter
	def NoOfSRTunnels(self, value):
		self._set_attribute('noOfSRTunnels', value)

	@property
	def NodePrefix(self):
		"""DEPRECATED Node Prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('nodePrefix')

	@property
	def NumberOfMappingIPV4Ranges(self):
		"""DEPRECATED Specifies the number of IPv4 mappings or range TLVs that each router in a DG can advertise.

		Returns:
			number
		"""
		return self._get_attribute('numberOfMappingIPV4Ranges')
	@NumberOfMappingIPV4Ranges.setter
	def NumberOfMappingIPV4Ranges(self, value):
		self._set_attribute('numberOfMappingIPV4Ranges', value)

	@property
	def NumberOfMappingIPV6Ranges(self):
		"""DEPRECATED Specifies the number of IPv6 mappings or range TLVs that each router in a DG can advertise.

		Returns:
			number
		"""
		return self._get_attribute('numberOfMappingIPV6Ranges')
	@NumberOfMappingIPV6Ranges.setter
	def NumberOfMappingIPV6Ranges(self, value):
		self._set_attribute('numberOfMappingIPV6Ranges', value)

	@property
	def OFlagOfSRv6Cap(self):
		"""DEPRECATED If set, it indicates that this packet is an operations and management (OAM) packet.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('oFlagOfSRv6Cap')

	@property
	def Overloaded(self):
		"""DEPRECATED Overloaded

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('overloaded')

	@property
	def PFlag(self):
		"""DEPRECATED No-PHP flag. If set, then the penultimate hop MUST NOT pop the Prefix-SID before delivering the packet to the node that advertised the Prefix-SID.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pFlag')

	@property
	def PSNPInterval(self):
		"""DEPRECATED PSNP Interval (ms)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('pSNPInterval')

	@property
	def PartitionRepair(self):
		"""DEPRECATED Partition Repair

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('partitionRepair')

	@property
	def PrefixAdvertisementType(self):
		"""DEPRECATED Prefix Advertisement Type

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('prefixAdvertisementType')

	@property
	def PrefixLength(self):
		"""DEPRECATED Prefix Length

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('prefixLength')

	@property
	def RFlag(self):
		"""DEPRECATED Redistribution flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rFlag')

	@property
	def Redistribution(self):
		"""DEPRECATED Redistribution

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('redistribution')

	@property
	def ReservedInsideSRv6CapFlag(self):
		"""DEPRECATED This is the reserved field (as part of Flags field of SRv6 Capability TLV)

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('reservedInsideSRv6CapFlag')

	@property
	def RtrcapId(self):
		"""DEPRECATED Router Capability Id

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rtrcapId')

	@property
	def RtrcapIdForSrv6(self):
		"""DEPRECATED Router Capability Id

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rtrcapIdForSrv6')

	@property
	def SBit(self):
		"""DEPRECATED Enabling S bit lets the IS-IS Router CAPABILITY TLV to get flooded across the entire routing domain, otherwise the TLV not be leaked between levels

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sBit')

	@property
	def SBitForSRv6Cap(self):
		"""DEPRECATED Enabling S bit lets the IS-IS Router CAPABILITY TLV to get flooded across the entire routing domain, otherwise the TLV not be leaked between levels

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sBitForSRv6Cap')

	@property
	def SIDIndexLabel(self):
		"""DEPRECATED SID/Index/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sIDIndexLabel')

	@property
	def SRAlgorithmCount(self):
		"""DEPRECATED SR Algorithm Count

		Returns:
			number
		"""
		return self._get_attribute('sRAlgorithmCount')
	@SRAlgorithmCount.setter
	def SRAlgorithmCount(self, value):
		self._set_attribute('sRAlgorithmCount', value)

	@property
	def SRGBRangeCount(self):
		"""DEPRECATED SRGB Range Count

		Returns:
			number
		"""
		return self._get_attribute('sRGBRangeCount')
	@SRGBRangeCount.setter
	def SRGBRangeCount(self, value):
		self._set_attribute('sRGBRangeCount', value)

	@property
	def SessionInfo(self):
		"""DEPRECATED Logs additional information about the session Information

		Returns:
			list(str[noIfaceUp|up])
		"""
		return self._get_attribute('sessionInfo')

	@property
	def SessionStatus(self):
		"""DEPRECATED Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.

		Returns:
			list(str[down|notStarted|up])
		"""
		return self._get_attribute('sessionStatus')

	@property
	def SrlbDescriptorCount(self):
		"""DEPRECATED Count of the SRLB descriptor entries, each being a tuple having format {Start SID/Label, SID Count}

		Returns:
			number
		"""
		return self._get_attribute('srlbDescriptorCount')
	@SrlbDescriptorCount.setter
	def SrlbDescriptorCount(self, value):
		self._set_attribute('srlbDescriptorCount', value)

	@property
	def SrlbFlags(self):
		"""DEPRECATED This specifies the value of the SRLB flags field

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('srlbFlags')

	@property
	def SrmsPreference(self):
		"""DEPRECATED This is used to associate a preference with SRMS advertisements and is being advertised as a sub-TLV in Router Capability TLV

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('srmsPreference')

	@property
	def StateCounts(self):
		"""DEPRECATED A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up

		Returns:
			dict(total:number,notStarted:number,down:number,up:number)
		"""
		return self._get_attribute('stateCounts')

	@property
	def Status(self):
		"""DEPRECATED Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			str(configured|error|mixed|notStarted|started|starting|stopping)
		"""
		return self._get_attribute('status')

	@property
	def TERouterId(self):
		"""DEPRECATED TE Router ID

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('tERouterId')

	@property
	def VFlag(self):
		"""DEPRECATED Value Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('vFlag')

	def update(self, EnableBIER=None, EnableSR=None, LocatorCount=None, MtCount=None, Name=None, NoOfBIERSubDomains=None, NoOfSRTunnels=None, NumberOfMappingIPV4Ranges=None, NumberOfMappingIPV6Ranges=None, SRAlgorithmCount=None, SRGBRangeCount=None, SrlbDescriptorCount=None):
		"""Updates a child instance of isisL3Router on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			EnableBIER (bool): Enable BIER
			EnableSR (bool): Enable Segment Routing
			LocatorCount (number): Locator Count
			MtCount (number): MT Count
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfBIERSubDomains (number): Number of BIER Sub Domains
			NoOfSRTunnels (number): Number of MPLS SR Tunnels
			NumberOfMappingIPV4Ranges (number): Specifies the number of IPv4 mappings or range TLVs that each router in a DG can advertise.
			NumberOfMappingIPV6Ranges (number): Specifies the number of IPv6 mappings or range TLVs that each router in a DG can advertise.
			SRAlgorithmCount (number): SR Algorithm Count
			SRGBRangeCount (number): SRGB Range Count
			SrlbDescriptorCount (number): Count of the SRLB descriptor entries, each being a tuple having format {Start SID/Label, SID Count}

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, EnableBIER=None, EnableSR=None, Errors=None, LocalSystemID=None, LocatorCount=None, MtCount=None, Name=None, NoOfBIERSubDomains=None, NoOfSRTunnels=None, NumberOfMappingIPV4Ranges=None, NumberOfMappingIPV6Ranges=None, SRAlgorithmCount=None, SRGBRangeCount=None, SessionInfo=None, SessionStatus=None, SrlbDescriptorCount=None, StateCounts=None, Status=None):
		"""Finds and retrieves isisL3Router data from the server.

		All named parameters support regex and can be used to selectively retrieve isisL3Router data from the server.
		By default the find method takes no parameters and will retrieve all isisL3Router data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			EnableBIER (bool): Enable BIER
			EnableSR (bool): Enable Segment Routing
			Errors (list(dict(arg1:str[None|/api/v1/sessions/1/ixnetwork/?deepchild=*],arg2:list[str]))): A list of errors that have occurred
			LocalSystemID (list(str)): System ID
			LocatorCount (number): Locator Count
			MtCount (number): MT Count
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario
			NoOfBIERSubDomains (number): Number of BIER Sub Domains
			NoOfSRTunnels (number): Number of MPLS SR Tunnels
			NumberOfMappingIPV4Ranges (number): Specifies the number of IPv4 mappings or range TLVs that each router in a DG can advertise.
			NumberOfMappingIPV6Ranges (number): Specifies the number of IPv6 mappings or range TLVs that each router in a DG can advertise.
			SRAlgorithmCount (number): SR Algorithm Count
			SRGBRangeCount (number): SRGB Range Count
			SessionInfo (list(str[noIfaceUp|up])): Logs additional information about the session Information
			SessionStatus (list(str[down|notStarted|up])): Current state of protocol session: Not Started - session negotiation not started, the session is not active yet. Down - actively trying to bring up a protocol session, but negotiation is didn't successfully complete (yet). Up - session came up successfully.
			SrlbDescriptorCount (number): Count of the SRLB descriptor entries, each being a tuple having format {Start SID/Label, SID Count}
			StateCounts (dict(total:number,notStarted:number,down:number,up:number)): A list of values that indicates the total number of sessions, the number of sessions not started, the number of sessions down and the number of sessions that are up
			Status (str(configured|error|mixed|notStarted|started|starting|stopping)): Running status of associated network element. Once in Started state, protocol sessions will begin to negotiate.

		Returns:
			self: This instance with matching isisL3Router data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of isisL3Router data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the isisL3Router data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, BIERNodePrefix=None, Active=None, AdvertiseNodeMsd=None, AdvertiseSRLB=None, AdvertiseSRMSPreference=None, Algorithm=None, AreaAddresses=None, AreaAuthenticationType=None, AreaTransmitPasswordOrMD5Key=None, Attached=None, BIERIPv6NodePrefix=None, BierNFlag=None, BierRFlag=None, CSNPInterval=None, ConfigureSIDIndexLabel=None, DBit=None, DBitForSRv6Cap=None, DiscardLSPs=None, Distribution=None, DomainAuthenticationType=None, DomainTransmitPasswordOrMD5Key=None, EFlag=None, EnableHelloPadding=None, EnableHitlessRestart=None, EnableHostName=None, EnableMTIPv6=None, EnableMappingServer=None, EnableTE=None, EnableWMforTE=None, EnableWideMetric=None, HitlessRestartMode=None, HitlessRestartTime=None, HitlessRestartVersion=None, HostName=None, IgnoreReceiveMD5=None, IncludeMaxSlMsd=None, IncludeMaximumEndDMsd=None, IncludeMaximumEndPopMsd=None, IncludeMaximumTEncapMsd=None, IncludeMaximumTInsertMsd=None, IncludePrefixAttrFlags=None, InterLSPsOrMGroupPDUBurstGap=None, Ipv4Flag=None, Ipv6Flag=None, Ipv6NodePrefix=None, Ipv6Srh=None, LFlag=None, LSPLifetime=None, LSPRefreshRate=None, LSPorMGroupPDUMinTransmissionInterval=None, Mask=None, MaxAreaAddresses=None, MaxEndDMsd=None, MaxEndPopMsd=None, MaxLSPSize=None, MaxLSPsOrMGroupPDUsPerBurst=None, MaxSlMsd=None, MaxTEncap=None, MaxTInsertMsd=None, NFlag=None, NodePrefix=None, OFlagOfSRv6Cap=None, Overloaded=None, PFlag=None, PSNPInterval=None, PartitionRepair=None, PrefixAdvertisementType=None, PrefixLength=None, RFlag=None, Redistribution=None, ReservedInsideSRv6CapFlag=None, RtrcapId=None, RtrcapIdForSrv6=None, SBit=None, SBitForSRv6Cap=None, SIDIndexLabel=None, SrlbFlags=None, SrmsPreference=None, TERouterId=None, VFlag=None):
		"""Base class infrastructure that gets a list of isisL3Router device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			BIERNodePrefix (str): optional regex of BIERNodePrefix
			Active (str): optional regex of active
			AdvertiseNodeMsd (str): optional regex of advertiseNodeMsd
			AdvertiseSRLB (str): optional regex of advertiseSRLB
			AdvertiseSRMSPreference (str): optional regex of advertiseSRMSPreference
			Algorithm (str): optional regex of algorithm
			AreaAddresses (str): optional regex of areaAddresses
			AreaAuthenticationType (str): optional regex of areaAuthenticationType
			AreaTransmitPasswordOrMD5Key (str): optional regex of areaTransmitPasswordOrMD5Key
			Attached (str): optional regex of attached
			BIERIPv6NodePrefix (str): optional regex of bIERIPv6NodePrefix
			BierNFlag (str): optional regex of bierNFlag
			BierRFlag (str): optional regex of bierRFlag
			CSNPInterval (str): optional regex of cSNPInterval
			ConfigureSIDIndexLabel (str): optional regex of configureSIDIndexLabel
			DBit (str): optional regex of dBit
			DBitForSRv6Cap (str): optional regex of dBitForSRv6Cap
			DiscardLSPs (str): optional regex of discardLSPs
			Distribution (str): optional regex of distribution
			DomainAuthenticationType (str): optional regex of domainAuthenticationType
			DomainTransmitPasswordOrMD5Key (str): optional regex of domainTransmitPasswordOrMD5Key
			EFlag (str): optional regex of eFlag
			EnableHelloPadding (str): optional regex of enableHelloPadding
			EnableHitlessRestart (str): optional regex of enableHitlessRestart
			EnableHostName (str): optional regex of enableHostName
			EnableMTIPv6 (str): optional regex of enableMTIPv6
			EnableMappingServer (str): optional regex of enableMappingServer
			EnableTE (str): optional regex of enableTE
			EnableWMforTE (str): optional regex of enableWMforTE
			EnableWideMetric (str): optional regex of enableWideMetric
			HitlessRestartMode (str): optional regex of hitlessRestartMode
			HitlessRestartTime (str): optional regex of hitlessRestartTime
			HitlessRestartVersion (str): optional regex of hitlessRestartVersion
			HostName (str): optional regex of hostName
			IgnoreReceiveMD5 (str): optional regex of ignoreReceiveMD5
			IncludeMaxSlMsd (str): optional regex of includeMaxSlMsd
			IncludeMaximumEndDMsd (str): optional regex of includeMaximumEndDMsd
			IncludeMaximumEndPopMsd (str): optional regex of includeMaximumEndPopMsd
			IncludeMaximumTEncapMsd (str): optional regex of includeMaximumTEncapMsd
			IncludeMaximumTInsertMsd (str): optional regex of includeMaximumTInsertMsd
			IncludePrefixAttrFlags (str): optional regex of includePrefixAttrFlags
			InterLSPsOrMGroupPDUBurstGap (str): optional regex of interLSPsOrMGroupPDUBurstGap
			Ipv4Flag (str): optional regex of ipv4Flag
			Ipv6Flag (str): optional regex of ipv6Flag
			Ipv6NodePrefix (str): optional regex of ipv6NodePrefix
			Ipv6Srh (str): optional regex of ipv6Srh
			LFlag (str): optional regex of lFlag
			LSPLifetime (str): optional regex of lSPLifetime
			LSPRefreshRate (str): optional regex of lSPRefreshRate
			LSPorMGroupPDUMinTransmissionInterval (str): optional regex of lSPorMGroupPDUMinTransmissionInterval
			Mask (str): optional regex of mask
			MaxAreaAddresses (str): optional regex of maxAreaAddresses
			MaxEndDMsd (str): optional regex of maxEndDMsd
			MaxEndPopMsd (str): optional regex of maxEndPopMsd
			MaxLSPSize (str): optional regex of maxLSPSize
			MaxLSPsOrMGroupPDUsPerBurst (str): optional regex of maxLSPsOrMGroupPDUsPerBurst
			MaxSlMsd (str): optional regex of maxSlMsd
			MaxTEncap (str): optional regex of maxTEncap
			MaxTInsertMsd (str): optional regex of maxTInsertMsd
			NFlag (str): optional regex of nFlag
			NodePrefix (str): optional regex of nodePrefix
			OFlagOfSRv6Cap (str): optional regex of oFlagOfSRv6Cap
			Overloaded (str): optional regex of overloaded
			PFlag (str): optional regex of pFlag
			PSNPInterval (str): optional regex of pSNPInterval
			PartitionRepair (str): optional regex of partitionRepair
			PrefixAdvertisementType (str): optional regex of prefixAdvertisementType
			PrefixLength (str): optional regex of prefixLength
			RFlag (str): optional regex of rFlag
			Redistribution (str): optional regex of redistribution
			ReservedInsideSRv6CapFlag (str): optional regex of reservedInsideSRv6CapFlag
			RtrcapId (str): optional regex of rtrcapId
			RtrcapIdForSrv6 (str): optional regex of rtrcapIdForSrv6
			SBit (str): optional regex of sBit
			SBitForSRv6Cap (str): optional regex of sBitForSRv6Cap
			SIDIndexLabel (str): optional regex of sIDIndexLabel
			SrlbFlags (str): optional regex of srlbFlags
			SrmsPreference (str): optional regex of srmsPreference
			TERouterId (str): optional regex of tERouterId
			VFlag (str): optional regex of vFlag

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def IsisStartRouter(self, *args, **kwargs):
		"""Executes the isisStartRouter operation on the server.

		Start ISIS Router

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		isisStartRouter()

		isisStartRouter(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		isisStartRouter(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('isisStartRouter', payload=payload, response_object=None)

	def IsisStopRouter(self, *args, **kwargs):
		"""Executes the isisStopRouter operation on the server.

		Stop ISIS Router

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		isisStopRouter()

		isisStopRouter(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		isisStopRouter(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('isisStopRouter', payload=payload, response_object=None)

	def RestartDown(self, *args, **kwargs):
		"""Executes the restartDown operation on the server.

		Stop and start interfaces and sessions that are in Down state.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		restartDown()

		restartDown(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		restartDown(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('restartDown', payload=payload, response_object=None)

	def Start(self, *args, **kwargs):
		"""Executes the start operation on the server.

		Start selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		start()

		start(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		start(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self, *args, **kwargs):
		"""Executes the stop operation on the server.

		Stop selected protocols.

		The IxNetwork modeling infrastructure allows for multiple method Signatures with the same name while python does not.
		The following correlates the modeling Signatures to the python *args variable length list:

		stop()

		stop(SessionIndices:list)
			Args:
				args[0] is SessionIndices (list(number)): This parameter requires an array of session numbers 0 1 2 3

		stop(SessionIndices:string)
			Args:
				args[0] is SessionIndices (str): This parameter requires a string of session numbers 1-4;6;7-12

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class IPv4PseudoNodeRoutes(Base):
	"""The IPv4PseudoNodeRoutes class encapsulates a system managed IPv4PseudoNodeRoutes node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the IPv4PseudoNodeRoutes property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'IPv4PseudoNodeRoutes'

	def __init__(self, parent):
		super(IPv4PseudoNodeRoutes, self).__init__(parent)

	@property
	def Tag(self):
		"""An instance of the Tag class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag.Tag)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.topology.tag import Tag
		return Tag(self)

	@property
	def Active(self):
		"""Whether this is to be advertised or not

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def Algorithm(self):
		"""Algorithm

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('algorithm')

	@property
	def ConfigureSIDIndexLabel(self):
		"""Configure SID/Index/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('configureSIDIndexLabel')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def Ipv4EFlag(self):
		"""Explicit NULL flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4EFlag')

	@property
	def Ipv4LFlag(self):
		"""Local Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4LFlag')

	@property
	def Ipv4Metric(self):
		"""Route Metric

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4Metric')

	@property
	def Ipv4NFlag(self):
		"""Nodal prefix flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4NFlag')

	@property
	def Ipv4PFlag(self):
		"""No-PHP flag. If set, then the penultimate hop MUST NOT pop the Prefix-SID before delivering the packet to the node that advertised the Prefix-SID.

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4PFlag')

	@property
	def Ipv4RFlag(self):
		"""Redistribution flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4RFlag')

	@property
	def Ipv4Redistribution(self):
		"""Redistribution

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4Redistribution')

	@property
	def Ipv4RouteOrigin(self):
		"""Route Origin

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4RouteOrigin')

	@property
	def Ipv4VFlag(self):
		"""Value Flag

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('ipv4VFlag')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def NetworkAddress(self):
		"""Network addresses of the simulated IPv4 network

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('networkAddress')

	@property
	def PrefixLength(self):
		"""Prefix

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('prefixLength')

	@property
	def RangeSize(self):
		"""Range Size

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('rangeSize')

	@property
	def SIDIndexLabel(self):
		"""SID/Index/Label

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('sIDIndexLabel')

	def update(self, Name=None):
		"""Updates a child instance of IPv4PseudoNodeRoutes on the server.

		This method has some named parameters with a type: obj (Multivalue).
		The Multivalue class has the associated documentation that details the possible values for those named parameters.

		Args:
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def find(self, Count=None, DescriptiveName=None, Name=None):
		"""Finds and retrieves IPv4PseudoNodeRoutes data from the server.

		All named parameters support regex and can be used to selectively retrieve IPv4PseudoNodeRoutes data from the server.
		By default the find method takes no parameters and will retrieve all IPv4PseudoNodeRoutes data from the server.

		Args:
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			self: This instance with matching IPv4PseudoNodeRoutes data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of IPv4PseudoNodeRoutes data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the IPv4PseudoNodeRoutes data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)

	def get_device_ids(self, PortNames=None, Active=None, Algorithm=None, ConfigureSIDIndexLabel=None, Ipv4EFlag=None, Ipv4LFlag=None, Ipv4Metric=None, Ipv4NFlag=None, Ipv4PFlag=None, Ipv4RFlag=None, Ipv4Redistribution=None, Ipv4RouteOrigin=None, Ipv4VFlag=None, NetworkAddress=None, PrefixLength=None, RangeSize=None, SIDIndexLabel=None):
		"""Base class infrastructure that gets a list of IPv4PseudoNodeRoutes device ids encapsulated by this object.

		Use the optional regex parameters in the method to refine the list of device ids encapsulated by this object.

		Args:
			PortNames (str): optional regex of port names
			Active (str): optional regex of active
			Algorithm (str): optional regex of algorithm
			ConfigureSIDIndexLabel (str): optional regex of configureSIDIndexLabel
			Ipv4EFlag (str): optional regex of ipv4EFlag
			Ipv4LFlag (str): optional regex of ipv4LFlag
			Ipv4Metric (str): optional regex of ipv4Metric
			Ipv4NFlag (str): optional regex of ipv4NFlag
			Ipv4PFlag (str): optional regex of ipv4PFlag
			Ipv4RFlag (str): optional regex of ipv4RFlag
			Ipv4Redistribution (str): optional regex of ipv4Redistribution
			Ipv4RouteOrigin (str): optional regex of ipv4RouteOrigin
			Ipv4VFlag (str): optional regex of ipv4VFlag
			NetworkAddress (str): optional regex of networkAddress
			PrefixLength (str): optional regex of prefixLength
			RangeSize (str): optional regex of rangeSize
			SIDIndexLabel (str): optional regex of sIDIndexLabel

		Returns:
			list(int): A list of device ids that meets the regex criteria provided in the method parameters

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._get_ngpf_device_ids(locals())

	def FetchAndUpdateConfigFromCloud(self, *args, **kwargs):
		"""Executes the fetchAndUpdateConfigFromCloud operation on the server.

		fetchAndUpdateConfigFromCloud(Mode:string)
			Args:
				args[0] is Mode (str): 

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self.href }
		for i in range(len(args)): payload['Arg%s' % (i + 2)] = args[i]
		for item in kwargs.items(): payload[item[0]] = item[1]
		return self._execute('fetchAndUpdateConfigFromCloud', payload=payload, response_object=None)

	def Start(self):
		"""Executes the start operation on the server.

		Start CPF control plane (equals to promote to negotiated state).

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('start', payload=payload, response_object=None)

	def Stop(self):
		"""Executes the stop operation on the server.

		Stop CPF control plane (equals to demote to PreValidated-DoDDone state).

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		payload = { "Arg1": self }
		return self._execute('stop', payload=payload, response_object=None)



# MIT LICENSE
#
# Copyright 1997 - 2019 by IXIA Keysight
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class MulticastLeafRange(Base):
	"""The MulticastLeafRange class encapsulates a user managed multicastLeafRange node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the MulticastLeafRange property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server using the find method.
	The internal properties list can be managed by the user by using the add and remove methods.
	"""

	_SDM_NAME = 'multicastLeafRange'

	def __init__(self, parent):
		super(MulticastLeafRange, self).__init__(parent)

	@property
	def GroupTrafficRange(self):
		"""An instance of the GroupTrafficRange class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastleafrange.grouptrafficrange.grouptrafficrange.GroupTrafficRange)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastleafrange.grouptrafficrange.grouptrafficrange import GroupTrafficRange
		return GroupTrafficRange(self)

	@property
	def OpaqueValueElement(self):
		"""An instance of the OpaqueValueElement class.

		Returns:
			obj(ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastleafrange.opaquevalueelement.opaquevalueelement.OpaqueValueElement)

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		from ixnetwork_restpy.testplatform.sessions.ixnetwork.vport.protocols.ldp.router.multicastleafrange.opaquevalueelement.opaquevalueelement import OpaqueValueElement
		return OpaqueValueElement(self)

	@property
	def ContinuousIncrOpaqueValuesAcrossRoot(self):
		"""It signifies the continuous increment of opaque values across root.

		Returns:
			bool
		"""
		return self._get_attribute('continuousIncrOpaqueValuesAcrossRoot')
	@ContinuousIncrOpaqueValuesAcrossRoot.setter
	def ContinuousIncrOpaqueValuesAcrossRoot(self, value):
		self._set_attribute('continuousIncrOpaqueValuesAcrossRoot', value)

	@property
	def Enabled(self):
		"""If true, enables the protocol.

		Returns:
			bool
		"""
		return self._get_attribute('enabled')
	@Enabled.setter
	def Enabled(self, value):
		self._set_attribute('enabled', value)

	@property
	def LabelValueStart(self):
		"""The first label in the range of labels.

		Returns:
			number
		"""
		return self._get_attribute('labelValueStart')
	@LabelValueStart.setter
	def LabelValueStart(self, value):
		self._set_attribute('labelValueStart', value)

	@property
	def LabelValueStep(self):
		"""The label value increment step for more than 1 range.

		Returns:
			number
		"""
		return self._get_attribute('labelValueStep')
	@LabelValueStep.setter
	def LabelValueStep(self, value):
		self._set_attribute('labelValueStep', value)

	@property
	def LspCountPerRoot(self):
		"""This is to specify how many different LSPs are created per Root.

		Returns:
			number
		"""
		return self._get_attribute('lspCountPerRoot')
	@LspCountPerRoot.setter
	def LspCountPerRoot(self, value):
		self._set_attribute('lspCountPerRoot', value)

	@property
	def LspType(self):
		"""The type of multicast LSP.

		Returns:
			str(p2mp)
		"""
		return self._get_attribute('lspType')

	@property
	def RootAddrCount(self):
		"""The root address count for this Multicast FEC range.

		Returns:
			number
		"""
		return self._get_attribute('rootAddrCount')
	@RootAddrCount.setter
	def RootAddrCount(self, value):
		self._set_attribute('rootAddrCount', value)

	@property
	def RootAddrStep(self):
		"""The Root Address increment step. This is applicable only if Root Address Count is greater than 1.

		Returns:
			str
		"""
		return self._get_attribute('rootAddrStep')
	@RootAddrStep.setter
	def RootAddrStep(self, value):
		self._set_attribute('rootAddrStep', value)

	@property
	def RootAddress(self):
		"""The root address of the multicast LSP.

		Returns:
			str
		"""
		return self._get_attribute('rootAddress')
	@RootAddress.setter
	def RootAddress(self, value):
		self._set_attribute('rootAddress', value)

	def update(self, ContinuousIncrOpaqueValuesAcrossRoot=None, Enabled=None, LabelValueStart=None, LabelValueStep=None, LspCountPerRoot=None, RootAddrCount=None, RootAddrStep=None, RootAddress=None):
		"""Updates a child instance of multicastLeafRange on the server.

		Args:
			ContinuousIncrOpaqueValuesAcrossRoot (bool): It signifies the continuous increment of opaque values across root.
			Enabled (bool): If true, enables the protocol.
			LabelValueStart (number): The first label in the range of labels.
			LabelValueStep (number): The label value increment step for more than 1 range.
			LspCountPerRoot (number): This is to specify how many different LSPs are created per Root.
			RootAddrCount (number): The root address count for this Multicast FEC range.
			RootAddrStep (str): The Root Address increment step. This is applicable only if Root Address Count is greater than 1.
			RootAddress (str): The root address of the multicast LSP.

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._update(locals())

	def add(self, ContinuousIncrOpaqueValuesAcrossRoot=None, Enabled=None, LabelValueStart=None, LabelValueStep=None, LspCountPerRoot=None, RootAddrCount=None, RootAddrStep=None, RootAddress=None):
		"""Adds a new multicastLeafRange node on the server and retrieves it in this instance.

		Args:
			ContinuousIncrOpaqueValuesAcrossRoot (bool): It signifies the continuous increment of opaque values across root.
			Enabled (bool): If true, enables the protocol.
			LabelValueStart (number): The first label in the range of labels.
			LabelValueStep (number): The label value increment step for more than 1 range.
			LspCountPerRoot (number): This is to specify how many different LSPs are created per Root.
			RootAddrCount (number): The root address count for this Multicast FEC range.
			RootAddrStep (str): The Root Address increment step. This is applicable only if Root Address Count is greater than 1.
			RootAddress (str): The root address of the multicast LSP.

		Returns:
			self: This instance with all currently retrieved multicastLeafRange data using find and the newly added multicastLeafRange data available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._create(locals())

	def remove(self):
		"""Deletes all the multicastLeafRange data in this instance from server.

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		self._delete()

	def find(self, ContinuousIncrOpaqueValuesAcrossRoot=None, Enabled=None, LabelValueStart=None, LabelValueStep=None, LspCountPerRoot=None, LspType=None, RootAddrCount=None, RootAddrStep=None, RootAddress=None):
		"""Finds and retrieves multicastLeafRange data from the server.

		All named parameters support regex and can be used to selectively retrieve multicastLeafRange data from the server.
		By default the find method takes no parameters and will retrieve all multicastLeafRange data from the server.

		Args:
			ContinuousIncrOpaqueValuesAcrossRoot (bool): It signifies the continuous increment of opaque values across root.
			Enabled (bool): If true, enables the protocol.
			LabelValueStart (number): The first label in the range of labels.
			LabelValueStep (number): The label value increment step for more than 1 range.
			LspCountPerRoot (number): This is to specify how many different LSPs are created per Root.
			LspType (str(p2mp)): The type of multicast LSP.
			RootAddrCount (number): The root address count for this Multicast FEC range.
			RootAddrStep (str): The Root Address increment step. This is applicable only if Root Address Count is greater than 1.
			RootAddress (str): The root address of the multicast LSP.

		Returns:
			self: This instance with matching multicastLeafRange data retrieved from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())

	def read(self, href):
		"""Retrieves a single instance of multicastLeafRange data from the server.

		Args:
			href (str): An href to the instance to be retrieved

		Returns:
			self: This instance with the multicastLeafRange data from the server available through an iterator or index

		Raises:
			NotFoundError: The requested resource does not exist on the server
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._read(href)
